@@ -11,13 +11,13 @@ from captur_ml_sdk.dtypes.exceptions import (
     VersionNotLiveError
 )
 
-def get_model_list_from_aiplatform():
+def get_model_list_from_aiplatform(location: str = "europe-west4"):
     """Returns list of trained models with details"""
-    api_endpoint = "us-central1-aiplatform.googleapis.com"
+    api_endpoint = f"{location}-aiplatform.googleapis.com"
     client_options = {"api_endpoint": api_endpoint}
     client = aiplatform.gapic.ModelServiceClient(client_options=client_options)
     models = client.list_models(
-        parent="projects/capturpwa/locations/us-central1")
+        parent=f"projects/capturpwa/locations/{location}")
     return models
 
 
@@ -73,7 +73,7 @@ def read_json_from_gcp_storage(file_path, project="capturpwa"):
     return data
 
 
-def get_all_available_models(with_filter=None):
+def get_all_available_models(with_filter=None, location: str = "europe-west4"):
     """
     Returns a refined list of available models.
     ----------------
@@ -81,6 +81,7 @@ def get_all_available_models(with_filter=None):
         with_filter : dict or None
             - example dict = {"model_display_name":"my_favourite_model"}
             default = None
+        location (str) - location to search for models
     returns:
         all_model_dicts : list[dict]
             - each dict contains:
@@ -91,7 +92,7 @@ def get_all_available_models(with_filter=None):
                 "update_time"
     ----------------
     """
-    models = get_model_list_from_aiplatform()
+    models = get_model_list_from_aiplatform(location)
 
     all_model_dicts = []
     for model in models:
@@ -111,7 +112,7 @@ def get_all_available_models(with_filter=None):
     return all_model_dicts
 
 
-def check_specific_version_exists(model_name, model_version):
+def check_specific_version_exists(model_name, model_version, location: str = "europe-west4"):
     """
     Checks whether a specific version of a model exists within GCP.
     ----------------
@@ -124,9 +125,9 @@ def check_specific_version_exists(model_name, model_version):
     """
     filters = {
         "display_name": model_name,
-        "name": f"projects/73629791501/locations/us-central1/models/{model_version}"
+        "name": f"projects/73629791501/locations/{location}/models/{model_version}"
     }
-    res = get_all_available_models(with_filter=filters)
+    res = get_all_available_models(with_filter=filters, location=location)
 
     specific_version_exists = False
 
@@ -250,11 +251,12 @@ def get_model_from_absolute_version(model_version, list_of_model_versions):
     return list_of_model_versions[model_version].get("model_id")
 
 
-def get_requested_model_id(model_name: str, model_version: str):
+def get_requested_model_id(model_name: str, model_version: str, location: str = "europe-west4"):
     """
     Returns a refined list of available models.
     ----------------
     args:
+        location (str): Location of model. Defaults to europe-west4
         model_name (str): The name of the model e.g. "pipeline_practice_model"
         model_version (str): Something like:
             "HEAD",
@@ -273,7 +275,7 @@ def get_requested_model_id(model_name: str, model_version: str):
     ----------------
     """
 
-    if not get_all_available_models(with_filter={"display_name": model_name}):
+    if not get_all_available_models(with_filter={"display_name": model_name}, location=location):
         raise ModelNotFoundError(f"Model: {model_name} not found.")
 
     model_version_data = get_list_of_versions_from_gcp(model_name)
@@ -284,8 +286,6 @@ def get_requested_model_id(model_name: str, model_version: str):
             f"Please specifiy the version directly or deploy a live version."
         )
 
-    model_id = None
-
     if re.match("[0-9]{19}", model_version):
         model_id = model_version
         if not check_specific_version_is_live(model_version_data, model_id):
@@ -302,11 +302,12 @@ def get_requested_model_id(model_name: str, model_version: str):
             model_version, model_version_data)
 
     if model_id is None:
-        raise TypeError(
-            f"{model_version} is not a valid format for a model version."
+        raise VersionNotFoundError(
+            f"Model {model_name} cannot get version {model_version}"
+            f"because there are only {len(model_version_data)} live versions."
         )
 
-    if not check_specific_version_exists(model_name, model_id):
+    if not check_specific_version_exists(model_name, model_id, location):
         raise VersionNotFoundError(
             f"Model {model_name} exists but {model_id} not found."
         )
